@@ -1,6 +1,6 @@
 /* APBasicLevel.m
  *
- * Copyright (C) 1999-2003 by vhf interservice GmbH
+ * Copyright (C) 1999-2005 by vhf interservice GmbH
  * Author: Georg Fleischmann
  *
  * Created:  1996-03-03
@@ -46,6 +46,11 @@
     return window;
 }
 
+- (NSString*)name
+{
+    return @"None";
+}
+
 - (void)update:sender
 {
 }
