@@ -5,7 +5,7 @@
  * Author:   Georg Fleischmann
  *
  * created:  2003-03-29
- * modified: 2007-07-22
+ * modified: 2010-05-22
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -89,6 +89,54 @@
     return instance;
 }
 
+- (NSString*)version
+{   NSDictionary    *infoDict = [[NSBundle mainBundle] infoDictionary];
+    NSString        *version = [infoDict objectForKey:@"CFBundleVersion"];
+
+    if ( ! version )
+        version = [infoDict objectForKey:@"NSVersion"];     // GNUstep
+    return version;
+}
+- (NSString*)compileDate
+{   char    *compileDate = __DATE__;    // Apr 10 2010
+    char    date[15];
+
+    if ( strlen(compileDate) == 11 )    // Apr 10 2010 -> 2010-04-10
+    {   NSArray *mArray;
+        char    mStr[4];
+        int     m;
+
+        strncpy(mStr, compileDate, 3); mStr[3] = 0;
+        mArray = [NSArray arrayWithObjects:@"Jan", @"Feb", @"Mar", @"Apr", @"May", @"Jun", @"Jul", @"Aug", @"Sep", @"Oct", @"Nov", @"Dec", nil];
+        if ( (m = [mArray indexOfObject:[NSString stringWithUTF8String:mStr]]) != NSNotFound )
+        {   m ++;
+            strncpy(date, compileDate+7, 4);                            // YYYY
+            date[4] = '-';
+            date[5] = (m >= 10) ? '1' : '0';                            // MM
+            if (m >= 10) m -= 10;
+            date[6] = '0' + m;
+            date[7] = '-';
+            date[8] = (compileDate[4] == ' ') ? '0' : compileDate[4];   // DD
+            date[9] = compileDate[5];
+            date[10] = 0;
+            compileDate = date;
+        }
+    }
+    if ( compileDate )
+        return [NSString stringWithCString:compileDate encoding:NSASCIIStringEncoding];
+    else
+        return nil;
+}
+- (NSString*)serialNo
+{
+    return nil;
+}
+- (NSString*)netId
+{
+    return nil;
+}
+
+
 /*  137.1234 ->  137  7'24"
  * -137.1234 -> -137  7'24"
  */
@@ -180,9 +228,9 @@ NSString *stringFromDeg(float deg)
                              object:nil];
 
     /* add a menu item for the AstroPanel */
-//#ifdef __APPLE__
-//    [toolMenu addItem:[NSMenuItem separatorItem]];
-//#endif
+#ifdef __APPLE__
+    [toolMenu addItem:[NSMenuItem separatorItem]];
+#endif
     [toolMenu addItemWithTitle:@"Astro Panel ..."
                         action:@selector(showAstroPanel:)
                  keyEquivalent:@""];
@@ -190,12 +238,24 @@ NSString *stringFromDeg(float deg)
     if (Prefs_ShowAstroPanel)
         [self showAstroPanel:self];
 
-    /* add a menu for our documentation */
+    /* Help Menu */
 #ifdef __APPLE__
-    [helpMenu addItemWithTitle:@"Cenon Astro"
-                        action:@selector(showAstroHelp:)
-                 keyEquivalent:@""];
-    [[[helpMenu itemArray] objectAtIndex:[[helpMenu itemArray] count]-1] setTarget:self];
+    {   int i;
+
+        /* redirect menu entries to Astro website */
+        for ( i=0; i<[helpMenu numberOfItems]; i++ )
+        {   NSMenuItem  *item = [helpMenu itemAtIndex:i];
+
+            if ( [item action] == @selector(showWebPage:) )
+                [item setTarget:self];  // redirect to our function (we are not first responder)
+        }
+
+        /* add a menu item for our documentation */
+        [helpMenu addItemWithTitle:@"Cenon Astro"
+                            action:@selector(showAstroHelp:)
+                     keyEquivalent:@""];
+        [[[helpMenu itemArray] objectAtIndex:[[helpMenu itemArray] count]-1] setTarget:self];
+    }
 #endif
 
     /* create event manager, city manager, time zone manager */
@@ -235,6 +295,27 @@ NSString *stringFromDeg(float deg)
     return astroPanel;
 }
 
+/* Show Web Page
+ * created: 2010-05-22
+ */
+- (void)showWebPage:(id)sender
+{   NSString    *site;
+    int         tag = [sender tag];
+
+	if ([sender isKindOfClass:[NSMatrix class]])
+		tag = [sender selectedTag];
+	switch (tag)
+    {
+        default: site = VHFLocalAstroString(@"http://www.cenon.info/astro"); break;                      // Web Site
+        case 1:  site = VHFLocalAstroString(@"http://www.cenon.info/astro/support_faq_gb.html"); break;  // FAQ
+        case 2:  site = VHFLocalAstroString(@"http://www.cenon.info/astro/releaseNotes_gb.html"); break; // Release Notes
+        case 3:  site = VHFLocalAstroString(@"mailto:service@vhf.de?subject=Cenon%20Astro%20Feedback"); break;  // eMail
+        case 4:  site = VHFLocalAstroString(@"http://www.cenon.info/astro/news/news_gb.html"); break;         // Check for Updates
+            //site = NSLocalizedString(@"http://www.cenon.biz/download_gb.html", Download); break;
+    }
+	[[NSWorkspace sharedWorkspace] openURL:[NSURL URLWithString:site]];
+}
+
 /* load PDF documentation
  * Note: each module can add a help menu entry to load it's docu
  * modified: 2007-07-19
