@@ -316,6 +316,8 @@
  * internal methods
  */
 
+/* modified: 2006-07-17
+ */
 - (void)loadStates
 {   NSString		*path;
     NSFileManager	*fileManager = [NSFileManager defaultManager];
@@ -327,13 +329,23 @@
     [folders release];
     folders = [NSMutableArray new];
 
+    /* load states from UserLibrary */
     path = [NSString stringWithFormat:@"%@/Astro/%@", userLibrary(), CITIES_FOLDER];
     if ([fileManager fileExistsAtPath:path])
         [folders addObjectsFromArray:[fileManager directoryContentsAtPath:path]];
 
+    /* add states from LocalLibrary, which are not in UserLibrary */
     path = [NSString stringWithFormat:@"%@/Astro/%@", localLibrary(), CITIES_FOLDER];
     if ([fileManager fileExistsAtPath:path])
-        [folders addObjectsFromArray:[fileManager directoryContentsAtPath:path]];
+    {   NSArray	*states = [fileManager directoryContentsAtPath:path];
+        int	i, cnt;
+
+        for (i=0, cnt=[states count]; i<cnt; i++)
+        {   NSString	*name = [states objectAtIndex:i];
+            if ( ![folders containsObject:name] )
+                [folders addObject:name];
+        }
+    }
 
     //folders = [[fileManager directoryContentsAtPath:path] mutableCopy];
     [folders sortUsingSelector:@selector(compare:)];
