@@ -1,11 +1,11 @@
 /* DocViewMap.m
  * Map additions for DocView.m
  *
- * Copyright (C) 2001-2007 by vhf interservice GmbH
+ * Copyright (C) 2001-2010 by Georg Fleischmann
  * Author:   Ilonka Fleischmann
  *
  * created:  2001-08-??
- * modified: 2007-09-03
+ * modified: 2010-04-22 (scale map to window size)
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the vhf Public License as
@@ -51,13 +51,13 @@ static NSArray	*colors = nil;
  * here we load this file, create a map object and store it
  */
 - (void)initMap
-{   NSString			*file = [[document filename] stringByAppendingPathComponent:MAP_INFOFILE];
-    NSDictionary		*dict;
-    Map				*map;
+{   NSString                *file = [[document filename] stringByAppendingPathComponent:MAP_INFOFILE];
+    NSDictionary            *dict;
+    Map                     *map;
     NSNotificationCenter	*notificationCenter = [NSNotificationCenter defaultCenter];
 
     if ( !(dict = [NSDictionary dictionaryWithContentsOfFile:file]) )
-	return;	// we are not a map
+        return;	// we are not a map
     map = [Map mapWithMapDictionary:dict];
     [statusDict setObject:map forKey:@"map"];
 
@@ -169,7 +169,7 @@ printf("%s  p = {%f %f} -> lon = %f, lat = %f\n", [[date description] cString],
 
 /* create tables of planets relating chart
  * positions, angles, mirrors, harmonies
- * modified: 2007-09-03
+ * modified: 2010-04-22
  */
 - (void)createMapWithCenter:(NSPoint)center size:(NSSize)size grid:(float)gridSize
                    features:(NSDictionary*)features
@@ -191,6 +191,16 @@ printf("%s  p = {%f %f} -> lon = %f, lat = %f\n", [[date description] cString],
         return;
     }
 
+    /* Scale chart to fit window size */
+    if ( ! [(DocWindow*)[self window] hasCoordDisplay] )
+    {   NSRect  bounds = [self bounds], frame  = [[self window] frame];
+        float   oldScale = [self scaleFactor];
+        float   scaleFactor = (frame.size.width  / bounds.size.width) / oldScale;
+
+        if ( Diff(scaleFactor, 1.0) > TOLERANCE )
+            [[self document] scale:scaleFactor :scaleFactor withCenter:NSZeroPoint];
+    }
+
     /* empty layers */
     if ([map needsCalculation])	// cia maps, only
         for ( l=0; l<(int)[layerList count]; l++ )
